summaryrefslogtreecommitdiffstats
path: root/pkg/commands
diff options
context:
space:
mode:
authorJesse Duffield <jessedduffield@gmail.com>2020-08-23 15:04:12 +1000
committerJesse Duffield <jessedduffield@gmail.com>2020-08-23 15:11:06 +1000
commit9f71c8d2b9cd971df454362dea34dd91af200568 (patch)
tree864a2d05e31754e68fd718d3e5bac5ebfb858d2c /pkg/commands
parentfce7cdcc0ae54ce625659a178af698db398c047e (diff)
rename Status to PatchStatus
Diffstat (limited to 'pkg/commands')
-rw-r--r--pkg/commands/commit_file.go4
-rw-r--r--pkg/commands/git.go2
2 files changed, 3 insertions, 3 deletions
diff --git a/pkg/commands/git.go b/pkg/commands/git.go
index d5577068a..64a4aa9d1 100644
--- a/pkg/commands/git.go
+++ b/pkg/commands/git.go
@@ -1080,7 +1080,7 @@ func (c *GitCommand) GetCommitFilesFromFilenames(filenames string, parent string
Parent: parent,
Name: name,
ChangeStatus: changeStatus,
- Status: status,
+ PatchStatus: status,
})
}
diff --git a/pkg/commands/commit_file.go b/pkg/commands/commit_file.go
index 9aca23855..c2131ace1 100644
--- a/pkg/commands/commit_file.go
+++ b/pkg/commands/commit_file.go
@@ -6,8 +6,8 @@ type CommitFile struct {
Parent string
Name string
- // Status tells us whether the file has been wholly or partially added to a patch. We might want to pull this logic up into the gui package and make it a map like we do with cherry picked commits
- Status int // one of 'WHOLE' 'PART' 'NONE'
+ // PatchStatus tells us whether the file has been wholly or partially added to a patch. We might want to pull this logic up into the gui package and make it a map like we do with cherry picked commits
+ PatchStatus int // one of 'WHOLE' 'PART' 'NONE'
ChangeStatus string // e.g. 'A' for added or 'M' for modified. This is based on the result from git diff --name-status
}